==> videorbits-2.201.tgz: videorbits-2.201/scripts/estpairwise.pl <==
#!/usr/bin/perl
#est_pairwise.pl

# number of steps is specified here, e.g. $steps = sprintf("4 8 7 6 5");
# does 8 steps at lowest resolution, 7 next, then 6, and finally 5 at max res

# $steps = sprintf("4 3 3 3 3"); # does 3 repetitions at each of 4 levels
# $steps = sprintf("4 4 3 2 1"); # does 4 then 3 then 2, then 1 (1 means none)

# except in rare and strange cases, more reps at each step gives better fit
# also, insanely large numbers of steps are good for demos: severe overkill
# but makes it stay on screen long enough to see, during a lecture demonstration

# in certain rare marginal cases if you do too many at beginning it won't work,
# e.g. i once shot video with a defective eyetap, and
# $steps = sprintf("5 32 16 8 4 2"); did not work, even though 5 4 4 4 4 4 did!

# here are some examples of what i've done in the past for eyetap video;
# just uncomment the one you want to try:
# $steps = sprintf("5 8 4 4 4 4"); #usually better because you more at low res
# $steps = sprintf("4 8 32 8 2");
# $steps = sprintf("3 32 8 2");
#$steps = sprintf("3 64 16 1");
$steps = sprintf("3 8 4 1");

if ($#ARGV < 0) {
  printf("Use: estpairwise v???.jpg # or use gash\n");
  printf("     estpairwise also autodetects jpg or ppm\n");
     die "     ERROR: YOU MUST SPECIFY SOME FILENAMES TO BE ESTimated$!\n";
}

$FILEOUT = sprintf("parameters_pairwise.txt"); # outfile accumulates all pairs
`touch $FILEOUT`;
`rm $FILEOUT`; # initialize to empty
##`touch $FILEOUT`;

for ($counter=0; $counter<=$#ARGV+1-2; $counter++) {
# $#ARGV is -1 if no arguments given; is 0 if 1 argument given, etc...
  $filea = $ARGV[$counter];
  $counterplusone = $counter+1;
  $fileb = $ARGV[$counterplusone];

  $fileout = sprintf("porkparameters%03d_%03d.txt", $counter+1,$counter);
  # last line of above file is the final answer
  # above file is cumulative result

  $periodpositiona = rindex($filea,"."); # right index, period from right
  $periodpositionb = rindex($fileb,".");
  $postfixa = substr($filea,$periodpositiona+1,3); # 2 char, e.g. JP or jp
  $postfixa =~ tr/[A-Z]/[a-z]/;
  #print $postfixa;
  $postfixb = substr($fileb,$periodpositionb+1,3);
  $postfixb =~ tr/[A-Z]/[a-z]/;
  #print $postfixb;
  #if it's JPEG, jpeg, JPG, or jpg:
    if (($postfixa eq "jpg") || ($postfixa eq "jpe")) { 
      #printf("about to djpeg $filea\n");
      `djpeg -grayscale $filea > deleteme_deletemea.pgm`;
      #$filea = "deleteme_deletemea.pgm";
    }
    else {
      `ppmtopgm $filea > deleteme_deletemea.pgm`
    }
  #if it's JPEG, jpeg, JPG, or jpg:
    if (($postfixb eq "jpg") || ($postfixb eq "jpe")) { 
      #printf("about to djpeg $fileb\n");
      `djpeg -grayscale $fileb > deleteme_deletemeb.pgm`;
      #$fileb = "deleteme_deletemeb.pgm";
    }
    else {
      `ppmtopgm $fileb > deleteme_deletemeb.pgm`
    }

  # now it's a PNM, pnm, PPM, ppm, PGM, or pgm:
  printf("estpairwise.pl: about to estpchirp2m $filea $fileb -outp $fileout -display -steps $steps\n");
#  `estpchirp2m $filea $fileb -outp $fileout -display -steps $steps > pork_stdout.txt`;
  `estpchirp2m deleteme_deletemea.pgm deleteme_deletemeb.pgm -outp $fileout -display -steps $steps > pork_stdout.txt`;

  # cat files together
  `tail -1 $fileout >> $FILEOUT`;  # cat into at first empty, accumulation
}

==> videorbits-2.205.tgz: videorbits-2.205/scripts/estpairwise.pl <==
#!/usr/bin/perl

use Image::Size;

#est_pairwise.pl

# number of steps is specified here, e.g. $steps = sprintf("4 8 7 6 5");
# does 8 steps at lowest resolution, 7 next, then 6, and finally 5 at max res

# $steps = sprintf("4 3 3 3 3"); # does 3 repetitions at each of 4 levels
# $steps = sprintf("4 4 3 2 1"); # does 4 then 3 then 2, then 1 (1 means none)

# except in rare and strange cases, more reps at each step gives better fit
# also, insanely large numbers of steps are good for demos: severe overkill
# but makes it stay on screen long enough to see, during a lecture demonstration

# in certain rare marginal cases if you do too many at beginning it won't work,
# e.g. i once shot video with a defective eyetap, and
# $steps = sprintf("5 32 16 8 4 2"); did not work, even though 5 4 4 4 4 4 did!

# here are some examples of what i've done in the past for eyetap video;
# just uncomment the one you want to try:
# $steps = sprintf("5 8 4 4 4 4"); #usually better because you more at low res
# $steps = sprintf("4 8 32 8 2");
# $steps = sprintf("3 32 8 2");
#$steps = sprintf("3 64 16 1");
#$steps = sprintf("3 8 4 8");
$steps = sprintf("2 18 8");
#$steps = sprintf("3 16 8 4");

if ($#ARGV < 0) {
  printf("Use: estpairwise v???.jpg # or use gash\n");
  printf("     estpairwise also autodetects jpg or ppm\n");
     die "     ERROR: YOU MUST SPECIFY SOME FILENAMES TO BE ESTimated$!\n";
}

$FILEOUT = sprintf("parameters_pairwise.txt"); # outfile accumulates all pairs
`touch $FILEOUT`;
`rm $FILEOUT`; # initialize to empty
##`touch $FILEOUT`;

for ($counter=0; $counter<=$#ARGV+1-2; $counter++) {
# $#ARGV is -1 if no arguments given; is 0 if 1 argument given, etc...
  $filea = $ARGV[$counter];
  $counterplusone = $counter+1;
  $fileb = $ARGV[$counterplusone];

  $fileout = sprintf("porkparameters%03d_%03d.txt", $counter+1,$counter);
  # last line of above file is the final answer
  # above file is cumulative result

  $periodpositiona = rindex($filea,"."); # right index, period from right
  $periodpositionb = rindex($fileb,".");
  $postfixa = substr($filea,$periodpositiona+1,3); # 2 char, e.g. JP or jp
  $postfixa =~ tr/[A-Z]/[a-z]/;
  #print $postfixa;
  $postfixb = substr($fileb,$periodpositionb+1,3);
  $postfixb =~ tr/[A-Z]/[a-z]/;
  #print $postfixb;
  #if it's JPEG, jpeg, JPG, or jpg:
    if (($postfixa eq "jpg") || ($postfixa eq "jpe")) { 
      #printf("about to djpeg $filea\n");
      `djpeg -grayscale $filea > deleteme_deletemea.pgm`;
      #$filea = "deleteme_deletemea.pgm";
    }
    else {
      `ppmtopgm $filea > deleteme_deletemea.pgm`
    }
  #if it's JPEG, jpeg, JPG, or jpg:
    if (($postfixb eq "jpg") || ($postfixb eq "jpe")) { 
      #printf("about to djpeg $fileb\n");
      `djpeg -grayscale $fileb > deleteme_deletemeb.pgm`;
      #$fileb = "deleteme_deletemeb.pgm";
    }
    else {
      `ppmtopgm $fileb > deleteme_deletemeb.pgm`
    }

    ($x, $y ) = imgsize("deleteme_deletemea.pgm");
    if( $x > 1000 ) {
	    $steps = sprintf("5 28 28 25 12 0");
	    `pnmscale -x 1024 deleteme_deletemeb.pgm > db.pgm`;
	    `pnmscale -x 1024 deleteme_deletemea.pgm > da.pgm`;
    }
    else {
            `cp deleteme_deletemeb.pgm db.pgm`;
            `cp deleteme_deletemea.pgm da.pgm`;
    }

    # now it's a PNM, pnm, PPM, ppm, PGM, or pgm:
    printf("estpairwise.pl: about to estpchirp2m $filea $fileb -outp $fileout -steps $steps\n");
    #  `estpchirp2m $filea $fileb -outp $fileout -display -steps $steps > pork_stdout.txt`;
    #system("est_trans_fft2 deleteme_deletemea.pgm deleteme_deletemeb.pgm > pork.txt");
    system("est_trans_fft2 da.pgm db.pgm > pork.txt");
    system("tail -1 pork.txt > bacon.txt");

    `estpchirp2m deleteme_deletemea.pgm deleteme_deletemeb.pgm -inp bacon.txt -outp $fileout -steps $steps > pork_stdout.txt`;

    # cat files together
    `tail -1 $fileout >> $FILEOUT`;  # cat into at first empty, accumulation
}
